==> ember-load-initializers-0.6.2.tgz: package/CHANGELOG.md <==
# Change Log

## [v0.6.0](https://github.com/ember-cli/ember-load-initializers/tree/v0.6.0) (2016-11-29)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.5.1...v0.6.0)

**Closed issues:**

- Shouldn't v0.5.1 be marked as the latest release? [\#29](https://github.com/ember-cli/ember-load-initializers/issues/29)
- Adding `__esModule: true` property [\#27](https://github.com/ember-cli/ember-load-initializers/issues/27)
- Build failure: File not found [\#25](https://github.com/ember-cli/ember-load-initializers/issues/25)
- ci [\#4](https://github.com/ember-cli/ember-load-initializers/issues/4)
- tests [\#3](https://github.com/ember-cli/ember-load-initializers/issues/3)
- examples [\#2](https://github.com/ember-cli/ember-load-initializers/issues/2)

**Merged pull requests:**

- flesh out as ember-cli add-on, this will allow us to use the existing… [\#31](https://github.com/ember-cli/ember-load-initializers/pull/31) ([stefanpenner](https://github.com/stefanpenner))
- Fix deopt with regex matches field load optimizing to undefined. [\#30](https://github.com/ember-cli/ember-load-initializers/pull/30) ([krisselden](https://github.com/krisselden))
- Avoid double walking of all modules [\#28](https://github.com/ember-cli/ember-load-initializers/pull/28) ([kratiahuja](https://github.com/kratiahuja))
- Updating README with note about compatibility [\#26](https://github.com/ember-cli/ember-load-initializers/pull/26) ([ColtonProvias](https://github.com/ColtonProvias))

## [v0.5.1](https://github.com/ember-cli/ember-load-initializers/tree/v0.5.1) (2016-02-03)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.5.0...v0.5.1)

**Closed issues:**

- Don't rely on globals [\#20](https://github.com/ember-cli/ember-load-initializers/issues/20)

**Merged pull requests:**

- Avoid using globals. [\#24](https://github.com/ember-cli/ember-load-initializers/pull/24) ([rwjblue](https://github.com/rwjblue))

## [v0.5.0](https://github.com/ember-cli/ember-load-initializers/tree/v0.5.0) (2016-02-03)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.1.7...v0.5.0)

**Closed issues:**

- Deprecation Ember 2+ [\#22](https://github.com/ember-cli/ember-load-initializers/issues/22)

**Merged pull requests:**

- Make ember-load-initializers an addon [\#23](https://github.com/ember-cli/ember-load-initializers/pull/23) ([josemarluedke](https://github.com/josemarluedke))

## [v0.1.7](https://github.com/ember-cli/ember-load-initializers/tree/v0.1.7) (2015-09-08)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.1.6...v0.1.7)

**Merged pull requests:**

- Prevent error when instance-initializers are found on Ember \< 1.12. [\#21](https://github.com/ember-cli/ember-load-initializers/pull/21) ([rwjblue](https://github.com/rwjblue))

## [v0.1.6](https://github.com/ember-cli/ember-load-initializers/tree/v0.1.6) (2015-08-14)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.1.5...v0.1.6)

## [v0.1.5](https://github.com/ember-cli/ember-load-initializers/tree/v0.1.5) (2015-06-25)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.1.4...v0.1.5)

**Merged pull requests:**

- Prefer Object.keys over Ember.keys [\#18](https://github.com/ember-cli/ember-load-initializers/pull/18) ([jmurphyau](https://github.com/jmurphyau))

## [v0.1.4](https://github.com/ember-cli/ember-load-initializers/tree/v0.1.4) (2015-04-06)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.1.3...v0.1.4)

**Merged pull requests:**

- better fix [\#16](https://github.com/ember-cli/ember-load-initializers/pull/16) ([stefanpenner](https://github.com/stefanpenner))

## [v0.1.3](https://github.com/ember-cli/ember-load-initializers/tree/v0.1.3) (2015-04-06)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.1.2...v0.1.3)

## [v0.1.2](https://github.com/ember-cli/ember-load-initializers/tree/v0.1.2) (2015-04-06)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.1.1...v0.1.2)

## [v0.1.1](https://github.com/ember-cli/ember-load-initializers/tree/v0.1.1) (2015-04-06)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.1.0...v0.1.1)

**Closed issues:**

- Published on Bower? [\#12](https://github.com/ember-cli/ember-load-initializers/issues/12)

**Merged pull requests:**

- dont auto-load jshint files [\#15](https://github.com/ember-cli/ember-load-initializers/pull/15) ([stefanpenner](https://github.com/stefanpenner))

## [v0.1.0](https://github.com/ember-cli/ember-load-initializers/tree/v0.1.0) (2015-04-02)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.0.2...v0.1.0)

**Closed issues:**

- Work needed here to support instance initializers [\#13](https://github.com/ember-cli/ember-load-initializers/issues/13)

**Merged pull requests:**

- initializersRegExp updated to handle instance initializers [\#14](https://github.com/ember-cli/ember-load-initializers/pull/14) ([jasonmit](https://github.com/jasonmit))
- Update organization name in repository URL [\#11](https://github.com/ember-cli/ember-load-initializers/pull/11) ([tricknotes](https://github.com/tricknotes))
- Auto-assign names to initializers if not already set [\#10](https://github.com/ember-cli/ember-load-initializers/pull/10) ([zeppelin](https://github.com/zeppelin))

## [v0.0.2](https://github.com/ember-cli/ember-load-initializers/tree/v0.0.2) (2014-05-27)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/0.0.1...v0.0.2)

**Merged pull requests:**

- Bump version. [\#8](https://github.com/ember-cli/ember-load-initializers/pull/8) ([abuiles](https://github.com/abuiles))
- Use strict prefix for comparison [\#7](https://github.com/ember-cli/ember-load-initializers/pull/7) ([jgwhite](https://github.com/jgwhite))
- Add license. [\#1](https://github.com/ember-cli/ember-load-initializers/pull/1) ([nathanhammond](https://github.com/nathanhammond))

## [0.0.1](https://github.com/ember-cli/ember-load-initializers/tree/0.0.1) (2014-04-12)


\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*

==> ember-load-initializers-1.1.0.tgz: package/CHANGELOG.md <==
# Change Log

## [v1.1.0](https://github.com/ember-cli/ember-load-initializers/tree/v1.1.0) (2018-04-17)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v1.0.0...v1.1.0)

**Closed issues:**

- module unification: initializer test files are included for `ember serve` [\#47](https://github.com/ember-cli/ember-load-initializers/issues/47)
- your releases page seems out of date [\#43](https://github.com/ember-cli/ember-load-initializers/issues/43)

**Merged pull requests:**

- allow colocated test files [\#53](https://github.com/ember-cli/ember-load-initializers/pull/53) ([GavinJoyce](https://github.com/GavinJoyce))
- Update ember-cli to 3.1.2 [\#52](https://github.com/ember-cli/ember-load-initializers/pull/52) ([eliasmelgaco](https://github.com/eliasmelgaco))
- bump dependencies, refactor tests slightly [\#51](https://github.com/ember-cli/ember-load-initializers/pull/51) ([efx](https://github.com/efx))
- fix linting config [\#49](https://github.com/ember-cli/ember-load-initializers/pull/49) ([efx](https://github.com/efx))
- internal clean up for contributing [\#48](https://github.com/ember-cli/ember-load-initializers/pull/48) ([efx](https://github.com/efx))
- fix code of conduct markdown [\#46](https://github.com/ember-cli/ember-load-initializers/pull/46) ([efx](https://github.com/efx))

## [v1.0.0](https://github.com/ember-cli/ember-load-initializers/tree/v1.0.0) (2017-03-25)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.6.3...v1.0.0)

**Closed issues:**

- Ember 2.12 incompatibility? [\#40](https://github.com/ember-cli/ember-load-initializers/issues/40)

**Merged pull requests:**

- Update to Babel 6. [\#41](https://github.com/ember-cli/ember-load-initializers/pull/41) ([rwjblue](https://github.com/rwjblue))
- CI: Enable automatic NPM deployment for tags [\#39](https://github.com/ember-cli/ember-load-initializers/pull/39) ([Turbo87](https://github.com/Turbo87))
- Update CHANGELOG [\#38](https://github.com/ember-cli/ember-load-initializers/pull/38) ([Turbo87](https://github.com/Turbo87))

## [v0.6.3](https://github.com/ember-cli/ember-load-initializers/tree/v0.6.3) (2016-12-06)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.6.2...v0.6.3)

**Merged pull requests:**

- Add ember-cli-babel as a dependency \(not devDep\). [\#37](https://github.com/ember-cli/ember-load-initializers/pull/37) ([rwjblue](https://github.com/rwjblue))

## [v0.6.2](https://github.com/ember-cli/ember-load-initializers/tree/v0.6.2) (2016-12-01)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.6.1...v0.6.2)

**Implemented enhancements:**

- Add Changelog [\#33](https://github.com/ember-cli/ember-load-initializers/issues/33)
- Add repository information to package.json [\#32](https://github.com/ember-cli/ember-load-initializers/issues/32)
- Clean up "package.json" file [\#35](https://github.com/ember-cli/ember-load-initializers/pull/35) ([Turbo87](https://github.com/Turbo87))
- Add Changelog [\#34](https://github.com/ember-cli/ember-load-initializers/pull/34) ([Turbo87](https://github.com/Turbo87))

**Merged pull requests:**

- Remove public directory files. [\#36](https://github.com/ember-cli/ember-load-initializers/pull/36) ([nathanhammond](https://github.com/nathanhammond))

## [v0.6.1](https://github.com/ember-cli/ember-load-initializers/tree/v0.6.1) (2016-11-30)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.6.0...v0.6.1)

## [v0.6.0](https://github.com/ember-cli/ember-load-initializers/tree/v0.6.0) (2016-11-29)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.5.1...v0.6.0)

**Closed issues:**

- Shouldn't v0.5.1 be marked as the latest release? [\#29](https://github.com/ember-cli/ember-load-initializers/issues/29)
- Adding `\_\_esModule: true` property [\#27](https://github.com/ember-cli/ember-load-initializers/issues/27)
- Build failure: File not found [\#25](https://github.com/ember-cli/ember-load-initializers/issues/25)
- ci [\#4](https://github.com/ember-cli/ember-load-initializers/issues/4)
- tests [\#3](https://github.com/ember-cli/ember-load-initializers/issues/3)
- examples [\#2](https://github.com/ember-cli/ember-load-initializers/issues/2)

**Merged pull requests:**

- flesh out as ember-cli add-on, this will allow us to use the existing… [\#31](https://github.com/ember-cli/ember-load-initializers/pull/31) ([stefanpenner](https://github.com/stefanpenner))
- Fix deopt with regex matches field load optimizing to undefined. [\#30](https://github.com/ember-cli/ember-load-initializers/pull/30) ([krisselden](https://github.com/krisselden))
- Avoid double walking of all modules [\#28](https://github.com/ember-cli/ember-load-initializers/pull/28) ([kratiahuja](https://github.com/kratiahuja))
- Updating README with note about compatibility [\#26](https://github.com/ember-cli/ember-load-initializers/pull/26) ([ColtonProvias](https://github.com/ColtonProvias))

## [v0.5.1](https://github.com/ember-cli/ember-load-initializers/tree/v0.5.1) (2016-02-03)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.5.0...v0.5.1)

**Closed issues:**

- Don't rely on globals [\#20](https://github.com/ember-cli/ember-load-initializers/issues/20)

**Merged pull requests:**

- Avoid using globals. [\#24](https://github.com/ember-cli/ember-load-initializers/pull/24) ([rwjblue](https://github.com/rwjblue))

## [v0.5.0](https://github.com/ember-cli/ember-load-initializers/tree/v0.5.0) (2016-02-03)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.1.7...v0.5.0)

**Closed issues:**

- Deprecation Ember 2+ [\#22](https://github.com/ember-cli/ember-load-initializers/issues/22)

**Merged pull requests:**

- Make ember-load-initializers an addon [\#23](https://github.com/ember-cli/ember-load-initializers/pull/23) ([josemarluedke](https://github.com/josemarluedke))

## [v0.1.7](https://github.com/ember-cli/ember-load-initializers/tree/v0.1.7) (2015-09-08)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.1.6...v0.1.7)

**Merged pull requests:**

- Prevent error when instance-initializers are found on Ember \< 1.12. [\#21](https://github.com/ember-cli/ember-load-initializers/pull/21) ([rwjblue](https://github.com/rwjblue))

## [v0.1.6](https://github.com/ember-cli/ember-load-initializers/tree/v0.1.6) (2015-08-14)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.1.5...v0.1.6)

## [v0.1.5](https://github.com/ember-cli/ember-load-initializers/tree/v0.1.5) (2015-06-25)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.1.4...v0.1.5)

**Merged pull requests:**

- Prefer Object.keys over Ember.keys [\#18](https://github.com/ember-cli/ember-load-initializers/pull/18) ([jmurphyau](https://github.com/jmurphyau))

## [v0.1.4](https://github.com/ember-cli/ember-load-initializers/tree/v0.1.4) (2015-04-06)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.1.3...v0.1.4)

**Merged pull requests:**

- better fix [\#16](https://github.com/ember-cli/ember-load-initializers/pull/16) ([stefanpenner](https://github.com/stefanpenner))

## [v0.1.3](https://github.com/ember-cli/ember-load-initializers/tree/v0.1.3) (2015-04-06)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.1.2...v0.1.3)

## [v0.1.2](https://github.com/ember-cli/ember-load-initializers/tree/v0.1.2) (2015-04-06)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.1.1...v0.1.2)

## [v0.1.1](https://github.com/ember-cli/ember-load-initializers/tree/v0.1.1) (2015-04-06)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.1.0...v0.1.1)

**Closed issues:**

- Published on Bower? [\#12](https://github.com/ember-cli/ember-load-initializers/issues/12)

**Merged pull requests:**

- dont auto-load jshint files [\#15](https://github.com/ember-cli/ember-load-initializers/pull/15) ([stefanpenner](https://github.com/stefanpenner))

## [v0.1.0](https://github.com/ember-cli/ember-load-initializers/tree/v0.1.0) (2015-04-02)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/v0.0.2...v0.1.0)

**Closed issues:**

- Work needed here to support instance initializers [\#13](https://github.com/ember-cli/ember-load-initializers/issues/13)

**Merged pull requests:**

- initializersRegExp updated to handle instance initializers [\#14](https://github.com/ember-cli/ember-load-initializers/pull/14) ([jasonmit](https://github.com/jasonmit))
- Update organization name in repository URL [\#11](https://github.com/ember-cli/ember-load-initializers/pull/11) ([tricknotes](https://github.com/tricknotes))
- Auto-assign names to initializers if not already set [\#10](https://github.com/ember-cli/ember-load-initializers/pull/10) ([zeppelin](https://github.com/zeppelin))

## [v0.0.2](https://github.com/ember-cli/ember-load-initializers/tree/v0.0.2) (2014-05-27)
[Full Changelog](https://github.com/ember-cli/ember-load-initializers/compare/0.0.1...v0.0.2)

**Merged pull requests:**

- Bump version. [\#8](https://github.com/ember-cli/ember-load-initializers/pull/8) ([abuiles](https://github.com/abuiles))
- Use strict prefix for comparison [\#7](https://github.com/ember-cli/ember-load-initializers/pull/7) ([jgwhite](https://github.com/jgwhite))
- Add license. [\#1](https://github.com/ember-cli/ember-load-initializers/pull/1) ([nathanhammond](https://github.com/nathanhammond))

## [0.0.1](https://github.com/ember-cli/ember-load-initializers/tree/0.0.1) (2014-04-12)


\* *This Change Log was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*
